@@ -20,6 +20,10 @@ class GitCliInterface(ABC):
     def squash_all(self, commit_message: str, skip_hooks: bool = False) -> UndoCommand:
         pass
 
+    @abstractmethod
+    def rebase(self, log_undoing_git_commands_title: bool = True) -> UndoCommand:
+        pass
+
     @abstractmethod
     def branch_exists(self, branch_name: BranchName) -> bool:
         pass
@@ -56,3 +60,7 @@ class GitCliInterface(ABC):
     @abstractmethod
     def fail_if_dirty(self):
         pass
+
+    @abstractmethod
+    def pull_with_rebase(self):
+        pass
